"""Phasor, analog and digital units."""

from espmu.enums import MeasurementType, AnlgMsrmnt


class Phunit:
    """Conversion factor and name for phasor channels.

    Parameters
    ----------
    phunit_hex_str: str
        Conversion factor field in hex str format.
    """
    def __init__(self, phunit_hex_str, debug=False):
        self._dbg = debug
        self.__phunit_hex = phunit_hex_str

        self.__volt_or_curr = None
        self.__parse_volt_or_curr()

        self.__value = None
        self.__parse_value()

        if self._dbg:
            print("PHUNIT: ", self.__volt_or_curr, " - ", self.__value, sep="")

    @property
    def volt_or_curr(self):
        """Voltage or current."""
        return self.__volt_or_curr

    @property
    def value(self):
        """Value of conversion factor."""
        return self.__value

    def __parse_volt_or_curr(self):
        self.__volt_or_curr = MeasurementType(
            int(self.__phunit_hex[0:2], 16)).name

    def __parse_value(self):
        self.__value = int(self.__phunit_hex[2:], 16)


class Anunit:
    """Conversion factor and name for analog channels.

    Parameters
    ----------
    anunit_hex_str: str
        Conversion factor for analog channels field in hex str format.
    """
    def __init__(self, anunit_hex_str, debug=False):
        self._dbg = debug
        self.__anunit_hex = anunit_hex_str

        self.__anlg_msrmnt = None
        self.__parse_anlg_msrmnt()

        self.__user_defined_scale = None
        self.__parse_user_defined_scale()

        if self._dbg:
            print("ANUNIT: ",
                  self.__anlg_msrmnt, " - ",
                  self.__user_defined_scale, sep="")

    @property
    def anlg_msrmnt(self):
        """Analog measurement type."""
        return self.__anlg_msrmnt

    @property
    def user_defined_scale(self):
        """User defined scaling."""
        return self.__user_defiend_scale

    def __parse_anlg_msrmnt(self):
        self.__anlg_msrmnt = AnlgMsrmnt(int(self.__anunit_hex[0:2], 16)).name

    def __parse_user_defined_scale(self):
        self.__user_defiend_scale = self.__anunit_hex[1:]


class Digunit:
    """Class for mask of digital status words.

    Parameters
    ----------
    digunit_hex_str: str
        Conversion factor for digital status channels field in hex str
        format.
    """
    def __init__(self, digunit_hex_str, debug=False):
        self._dbg = debug
        self.__digunit_hex = digunit_hex_str
        if self._dbg:
            print("DIGUNIT: ", self.__digunit_hex)

    @property
    def digunit_hex(self):
        """Conversion factor in hex str."""
        return self.__digunit_hex
