import unittest
from espmu.config_frame import ConfigFrame


class TestConfigFrame(unittest.TestCase):
    def test_empty(self):
        with self.assertRaises(IndexError):
            ConfigFrame("")

    def test_somethig_correct(self):
        with open("test/testdata/config.txt") as buf:
            data = buf.read()
        frame = ConfigFrame(data[:8])
        frame.frame = data
        frame.finishParsing()

        self.assertEqual(frame.chk, "35C\n")
        self.assertEqual(frame.datarate, 50)
        self.assertEqual(frame.fracsec, 828)
        self.assertEqual(frame.framesize, 1174)
        self.assertEqual(frame.idcode, 1)
        self.assertEqual(frame.length, 2344)
        self.assertEqual(frame.num_pmu, 1)

        self.assertEqual(frame.soc.dd, 28)
        self.assertEqual(frame.soc.ff, 0)
        self.assertEqual(frame.soc.formatted, "2021/04/28 09:40:23")
        self.assertEqual(frame.soc.hh, 9)
        self.assertEqual(frame.soc.mi, 40)
        self.assertEqual(frame.soc.mm, 4)
        self.assertEqual(frame.soc.secCount, 1619592023)
        self.assertEqual(frame.soc.ss, 23)
        self.assertEqual(frame.soc.utcSec, 1619602823.0)
        self.assertEqual(frame.soc.yyyy, 2021)

        self.assertEqual(len(frame.stations), 1)
        self.assertEqual(frame.sync.frameType, 'Config2')
        self.assertEqual(frame.sync.frameVers, 1)

        self.assertEqual(frame.time_base.baseDecStr, 1000)
        self.assertEqual(frame.time_base.flagsBinStr, '00000000')
        self.assertEqual(frame.time_base.timeBaseHex, '000003E8')

        self.assertEqual(frame.tq, 0)
