import unittest
from espmu.enums import MeasurementType, AnlgMsrmnt
from espmu.units import Phunit, Anunit, Digunit


class TestPhunit(unittest.TestCase):
    def test_empty(self):
        with self.assertRaises(ValueError):
            Phunit("")

    def test_voltage(self):
        unit = Phunit("000186A0")
        self.assertEqual(unit.volt_or_curr, MeasurementType.VOLTAGE.name)
        self.assertEqual(unit.value, 100000)

    def test_current(self):
        unit = Phunit("010186A0")
        self.assertEqual(unit.volt_or_curr, MeasurementType.CURRENT.name)
        self.assertEqual(unit.value, 100000)


class TestAnunit(unittest.TestCase):
    def test_empty(self):
        with self.assertRaises(ValueError):
            Anunit("")

    def test_rms(self):
        unit = Anunit("010186A0")
        self.assertEqual(unit.anlg_msrmnt, AnlgMsrmnt.RMS.name)


class TestDigunit(unittest.TestCase):
    def test_digunit(self):
        unit = Digunit("0000001F")
        self.assertEqual(unit.digunit_hex, "0000001F")
